"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _assert = _interopRequireDefault(require("assert"));

var _eventstoreBase = require("@resolve-js/eventstore-base");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const describe = async (pool, options) => {
  const {
    executeStatement,
    secretsTableName,
    escapeId,
    escape,
    eventsTableName
  } = pool;
  const eventsTableNameAsId = escapeId(eventsTableName);
  const secretsTableNameAsId = escapeId(secretsTableName);
  const freezeTableName = `${eventsTableName}-freeze`;
  let cursor = undefined;

  if (options && options.calculateCursor) {
    const existingThreads = await executeStatement(`
    SELECT "threadId", MAX("threadCounter") AS "threadCounter" FROM 
    ${eventsTableNameAsId} GROUP BY "threadId" ORDER BY "threadId" ASC`);
    const threadCounters = new Array(_eventstoreBase.THREAD_COUNT);
    threadCounters.fill(-1);

    for (const existingThread of existingThreads) {
      threadCounters[existingThread.threadId] = existingThread.threadCounter;
    }

    for (let i = 0; i < threadCounters.length; ++i) {
      threadCounters[i]++;
    }

    cursor = (0, _eventstoreBase.threadArrayToCursor)(threadCounters);
  }

  const rows = await executeStatement(`SELECT
    (SELECT COUNT(*) FROM ${eventsTableNameAsId}) AS "eventCount",
    (SELECT COUNT(*) FROM ${secretsTableNameAsId}) AS "secretCount",
    (SELECT COUNT(*) FROM ${secretsTableNameAsId} WHERE "secret" IS NOT NULL) AS "setSecretCount",
    (SELECT COUNT(*) FROM ${secretsTableNameAsId} WHERE "secret" IS NULL) AS "deletedSecretCount", 
    (SELECT "timestamp" FROM ${eventsTableNameAsId} ORDER BY "timestamp" DESC LIMIT 1) AS "lastEventTimestamp",
    (SELECT EXISTS (SELECT * FROM "sqlite_master" WHERE "type" = 'table' AND "name" = ${escape(freezeTableName)})) AS "isFrozen"
    `);

  _assert.default.strictEqual(rows.length, 1, 'Wrong number of description rows');

  const row = rows[0];
  return {
    eventCount: +row.eventCount,
    secretCount: +row.secretCount,
    setSecretCount: +row.setSecretCount,
    deletedSecretCount: +row.deletedSecretCount,
    lastEventTimestamp: +row.lastEventTimestamp,
    isFrozen: !!row.isFrozen,
    cursor: cursor
  };
};

var _default = describe;
exports.default = _default;
//# sourceMappingURL=describe.js.map